..
    This file is part of Invenio.
    Copyright (C) 2015, 2016 CERN.

    Invenio is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Invenio is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Invenio; if not, write to the
    Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA 02111-1307, USA.

    In applying this license, CERN does not
    waive the privileges and immunities granted to it by virtue of its status
    as an Intergovernmental Organization or submit itself to any jurisdiction.


Authors
=======

Invenio module for common role based access control.

- Adrian Pawel Baran <adrian.pawel.baran@cern.ch>
- Alberto Pepe <alberto.pepe@cern.ch>
- Alessio Deiana <alessio.deiana@cern.ch>
- Alper Cinar <alper@srdc.com.tr>
- Benoit Thiell <bthiell@cfa.harvard.edu>
- Eirini Psallida <eirini.psallida@cern.ch>
- Esteban J. G. Gabancho <esteban.jose.garcia.gabancho@cern.ch>
- Gabriel Hase <gabriel.hase@cern.ch>
- Gregory Favre <gregory.favre@cern.ch>
- Guillaume Lastecoueres <PX9e@gmx.fr>
- Harris Tzovanakis <me@drjova.com>
- Henning Weiler <henning.weiler@cern.ch>
- Jan Aage Lavik <jan.age.lavik@cern.ch>
- Jan Stypka <jan.stypka@cern.ch>
- Javier Delgado Fernandez <javier.delgado.fernandez@cern.ch>
- Javier Martin Montull <javier.martin.montull@cern.ch>
- Jerome Caffaro <jerome.caffaro@cern.ch>
- Jiri Kuncar <jiri.kuncar@cern.ch>
- Joaquim Rodrigues Silvestre <joaquim.rodrigues.silvestre@cern.ch>
- Jochen Klein <j.klein@cern.ch>
- Joe MacMahon <joe.macmahon@cern.ch>
- Kamil Neczaj <kneczaj@gmail.com>
- Lars Christian Raae <lars.christian.raae@cern.ch>
- Lars Holm Nielsen <lars.holm.nielsen@cern.ch>
- Leonardo Rossi <leonardo.r@cern.ch>
- Ludmila Marian <ludmila.marian@gmail.com>
- Marco Neumann <marco@crepererum.net>
- Marcus Johansson <marcus.johansson@cern.ch>
- Marko Niinimaki <manzikki@gmail.com>
- Mathieu Barras <mbarras@gmail.com>
- Mikael Vik <mikael.vik@cern.ch>
- Nikolaos Kasioumis <nikolaos.kasioumis@cern.ch>
- Patrick Glauner <patrick.oliver.glauner@cern.ch>
- Paulo Cabral <paulo.cabral@cern.ch>
- Peter Halliday <phalliday@cornell.edu>
- Radoslav Ivanov <radoslav.ivanov@cern.ch>
- Raquel Jimenez Encinar <raquel.jimenez.encinar@cern.ch>
- Roman Chyla <roman.chyla@cern.ch>
- Sami Hiltunen <sami.mikael.hiltunen@cern.ch>
- Samuele Kaplun <samuele.kaplun@cern.ch>
- Theodoropoulos Theodoros <theod@lib.auth.gr>
- Thomas Baron <thomas.baron@cern.ch>
- Tibor Simko <tibor.simko@cern.ch>
- Trond Aksel Myklebust <trond.aksel.myklebust@cern.ch>
- Yoan Blanc <yoan.blanc@cern.ch>
